import Header from "@/Components/Header";
import React, { useEffect, useState, forwardRef } from "react";
import Footer from "@/Components/Footer";
import InstagramFeeds from "@/Components/InstagramFeeds";
import OfferPackages from "@/Components/OfferPackages";
import Icon from "@mdi/react";
// import AdSense from "react-adsense";

import {
    mdiCameraOutline,
    mdiCheckOutline,
    mdiStarHalf,
    mdiStar,
    mdiCheckCircle,
    mdiCheckCircleOutline,
    mdiPlus,
    mdiMinus,
    mdiCalendar,
    mdiChevronLeft,
    mdiNaturePeople,
    mdiCurrencyBtc,
    mdiCurrencyUsd,
    mdiMapMarker,
    mdiMapMarkerOutline,
} from "@mdi/js";
import { router, usePage, Link, Head } from "@inertiajs/react";
import FlashMessages from "@/Components/FlashMessages";
import GalleryLocationComponent from "@/Components/GalleryLocationComponent";
import Faqs from "@/Components/Faqs";
import ImageViewModal from "@/Components/ImageViewModal";

import dayjs from "dayjs";
import { DemoContainer, DemoItem } from "@mui/x-date-pickers/internals/demo";
import { AdapterDayjs } from "@mui/x-date-pickers/AdapterDayjs";
import { LocalizationProvider } from "@mui/x-date-pickers/LocalizationProvider";

import { DateRangePicker } from "@mui/x-date-pickers-pro/DateRangePicker";

import {
    Dialog,
    DialogContent,
    IconButton,
    TextField,
    Tooltip,
    Button,
    Typography,
    Box,
} from "@mui/material";

import PropTypes from "prop-types";
import SwipeableViews from "react-swipeable-views";
import { useTheme } from "@mui/material/styles";
import AppBar from "@mui/material/AppBar";
import Tabs from "@mui/material/Tabs";
import Tab from "@mui/material/Tab";
import PhoneInput from "react-phone-input-2";
import "react-phone-input-2/lib/material.css";

export default function Welcome() {
    const { tourPackage, auth, flash } = usePage().props;
    const user = auth.user;
    const [selectedImage, setSelectedImage] = useState(null);
    const [showDropDown, setShowDropDown] = useState(true);
    const [loading, setLoading] = useState(false);
    const [name, setName] = useState(user ? user.name : null);
    const [phone, setPhone] = useState(user ? user.phone : null);
    const [email, setEmail] = useState(user ? user.email : null);
    const [message, setMessage] = useState(null);
    const [country, setCountry] = useState(null);

    const [open, setOpen] = React.useState(false);
    const [imageUrl, setImageUrl] = React.useState(null);
    useEffect(() => {
        setMessage(null);
        setEmail(null);
        setPhone(null);
        setName(null);
        setLoading(false);
    }, [flash]);
    const theme = useTheme();
    const [tabValue, setTabValue] = React.useState(0);

    function generateRandomNumber() {
        return Math.floor(Math.random() * (8 - 4 + 1)) + 4;
    }
    const showImageModal = (url) => {
        setImageUrl(url);
        setOpen(true);
    };
    const handleChange = (event, newValue) => {
        event.preventDefault();
        setTabValue(newValue);
    };

    const handleChangeIndex = (index) => {
        setTabValue(index);
    };
    const [value, setValue] = React.useState([
        dayjs("2022-04-17"),
        dayjs("2022-04-21"),
    ]);

    function TabPanel(props) {
        const { children, value, index, ...other } = props;

        return (
            <div
                role="tabpanel"
                hidden={value !== index}
                id={`full-width-tabpanel-${index}`}
                aria-labelledby={`full-width-tab-${index}`}
                {...other}
            >
                {value === index && (
                    <Box sx={{ p: 3 }}>
                        <Typography>{children}</Typography>
                    </Box>
                )}
            </div>
        );
    }

    TabPanel.propTypes = {
        children: PropTypes.node,
        index: PropTypes.number.isRequired,
        value: PropTypes.number.isRequired,
    };
    function a11yProps(index) {
        return {
            id: `full-width-tab-${index}`,
            "aria-controls": `full-width-tabpanel-${index}`,
        };
    }

    const [adultCount, setAdultCount] = useState(1);
    const [childCount, setChildCount] = useState(0);
    const [roomCount, setRoomCount] = useState(1);

    const handleIncrement = (type) => {
        switch (type) {
            case "adult":
                setAdultCount(adultCount + 1);
                break;
            case "child":
                setChildCount(childCount + 1);
                break;
            case "room":
                setRoomCount(roomCount + 1);
                break;
            default:
                break;
        }
    };

    const handleDecrement = (type) => {
        switch (type) {
            case "adult":
                if (adultCount > 1) {
                    setAdultCount(adultCount - 1);
                }
                break;
            case "child":
                if (childCount > 0) {
                    setChildCount(childCount - 1);
                }
                break;
            case "room":
                if (roomCount > 1) {
                    setRoomCount(roomCount - 1);
                }
                break;
            default:
                break;
        }
    };
    const PickersComponent = forwardRef(({ ...props }, ref) => {
        return (
            <TextField
                inputRef={ref}
                fullWidth
                {...props}
                label={props.label || ""}
                sx={{ width: "100%" }}
                error={props.error}
            />
        );
    });
    return (
        <>
            <Head title={`${tourPackage.name.replace(/\s+/g, "-")}`} />

            <ImageViewModal
                open={open}
                image={imageUrl}
                handleClose={() => {
                    setOpen(false);
                    setImageUrl(null);
                }}
            />
            <FlashMessages />
            <div>
                {/*========== HEADER STYLE ONE START ==========*/}
                <Header fixed={false} />
                {/*========== HEADER STYLE ONE END ==========*/}
                <div className="bg-gradient-to-t pt-2 to-[#FFF1EC] from-white">
                    <div className="md:flex">
                        <div className="lg:w-1/2 md:w-1/2 p-1">
                            <div
                                className="group relative cursor-pointer overflow-hidden"
                                onClick={() =>
                                    showImageModal(tourPackage.cover_image)
                                }
                            >
                                <img
                                    src={`/${tourPackage.cover_image}`}
                                    alt="placeholder"
                                    className="w-full"
                                />
                                <div className="inset-0 absolute bg-dark-1 bg-opacity-30 opacity-0 top-0 left-0 flex duration-300 hover:opacity-100 justify-center items-center">
                                    <div className="h-11 w-11 bg-primary-1 text-white rounded-full inline-flex justify-center items-center text-2md">
                                        <Icon
                                            path={mdiCameraOutline}
                                            size={0.8}
                                            className="text-white"
                                        />
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div className="lg:w-1/2 md:w-1/2">
                            <div className="grid lg:grid-cols-2  gap-2  md:grid-cols-2 grid-cols-1">
                                {/* <div className="w-full p-1">
                                    <div className="group relative overflow-hidden">
                                        <img
                                            src="/assets/images/packages/sl4.webp"
                                            alt=""
                                            className="w-full"
                                        />
                                        <a
                                            src="/assets/images/packages/sl4.webp"
                                            className="inset-0 absolute bg-dark-1 bg-opacity-30 opacity-0 top-0 left-0 flex duration-300 hover:opacity-100 justify-center items-center"
                                        >
                                            <div className="h-11 w-11 bg-primary-1 text-white rounded-full inline-flex justify-center items-center text-2md">
                                                <Icon
                                                    path={mdiCameraOutline}
                                                    size={0.8}
                                                    className="text-white"
                                                />
                                            </div>
                                        </a>
                                    </div>
                                </div> */}
                                {tourPackage.imagesTop.map((item, index) => (
                                    <>
                                        <div
                                            onClick={() =>
                                                showImageModal(item.image)
                                            }
                                            key={index}
                                            className="after:content relative group mb-0 block w-full cursor-pointer after:pointer-events-none after:absolute after:inset-0 after:rounded-lg after:shadow-highlight"
                                        >
                                            <img
                                                className="transform rounded-lg brightness-90 transition will-change-auto group-hover:brightness-110"
                                                style={{
                                                    transform:
                                                        "translate3d(0, 0, 0)",
                                                }}
                                                placeholder="blur"
                                                // blurDataURL={blurDataUrl}
                                                src={`/${item.image}`}
                                                // src="/assets/images/packages/sl5.webp"
                                                width={720}
                                                height={480}
                                                sizes="(max-width: 640px) 100vw,(max-width: 1280px) 50vw,(max-width: 1536px) 33vw,25vw"
                                            />
                                            <a
                                                src="/assets/images/packages/sl4.webp"
                                                className="inset-0 absolute bg-dark-1 bg-opacity-30 opacity-0 top-0 left-0 flex duration-300 hover:opacity-100 justify-center items-center"
                                            >
                                                <div className="h-11 w-11 bg-primary-1 text-white rounded-full inline-flex justify-center items-center text-2md">
                                                    <Icon
                                                        path={mdiCameraOutline}
                                                        size={0.8}
                                                        className="text-white"
                                                    />
                                                </div>
                                            </a>
                                        </div>
                                    </>
                                ))}
                                {/* <div className="w-1/2 p-1"> */}
                                {/* <div className="group relative overflow-hidden">
                                        <img
                                            src="/assets/images/packages/sl4.webp"
                                            alt="placeholder"
                                            className="w-full"
                                        />
                                        <a
                                            href="/assets/images/packages/sl4.webp"
                                            data-fancybox="details"
                                            className="inset-0 absolute bg-dark-1 bg-opacity-30 opacity-0 top-0 left-0 flex duration-300 hover:opacity-100 justify-center items-center"
                                        >
                                            <div className="h-11 w-11 bg-primary-1 text-white rounded-full inline-flex justify-center items-center text-2md">
                                                <Icon
                                                    path={mdiCameraOutline}
                                                    size={0.8}
                                                    className="text-white"
                                                />
                                            </div>
                                        </a>
                                    </div> */}

                                {/* </div> */}
                            </div>
                            {/* <div className="flex">
                                <div className="w-1/2 p-1">
                                    <div className="group relative overflow-hidden">
                                        <img
                                            src="/assets/images/packages/sl3.webp"
                                            alt="placeholder"
                                            className="w-full"
                                        />
                                        <a
                                            href="/assets/images/packages/sl3.webp"
                                            data-fancybox="details"
                                            className="inset-0 absolute bg-dark-1 bg-opacity-30 opacity-0 top-0 left-0 flex duration-300 hover:opacity-100 justify-center items-center"
                                        >
                                            <div className="h-11 w-11 bg-primary-1 text-white rounded-full inline-flex justify-center items-center text-2md">
                                                <Icon
                                                    path={mdiCameraOutline}
                                                    size={0.8}
                                                    className="text-white"
                                                />
                                            </div>
                                        </a>
                                    </div>
                                </div>
                                <div className="w-1/2 p-1">
                                    <div className="group relative overflow-hidden">
                                        <img
                                            src="/assets/images/packages/sl2.webp"
                                            alt="placeholder"
                                            className="w-full"
                                        />
                                        <a
                                            href="/assets/images/packages/sl2.webp"
                                            data-fancybox="details"
                                            className="inset-0 absolute bg-dark-1 bg-opacity-30 opacity-0 top-0 left-0 flex duration-300 hover:opacity-100 justify-center items-center"
                                        >
                                            <div className="h-11 w-11 bg-primary-1 text-white rounded-full inline-flex justify-center items-center text-2md">
                                                <Icon
                                                    path={mdiCameraOutline}
                                                    size={0.8}
                                                    className="text-white"
                                                />
                                            </div>
                                        </a>
                                    </div>
                                </div>
                            </div> */}
                        </div>
                    </div>
                    <div className="container">
                        <div className="flex flex-wrap justify-between pb-8 pt-6 mb-8 border-b border-stock-1">
                            <div className="pt-2">
                                <h3 className="lg:text-2xl md:text-xl text-lg text-dark-1 leading-[1.42] font-medium">
                                    {tourPackage.name}
                                </h3>
                                <div className="flex items-center mt-2">
                                    <ul className="flex lg:gap-3 gap-2 text-primary-1 mr-3 text-sm">
                                        <li>
                                            <Icon
                                                path={mdiStar}
                                                size={0.8}
                                                className="text-primary-1 text-center"
                                            />
                                        </li>
                                        <li>
                                            <Icon
                                                path={mdiStar}
                                                size={0.8}
                                                className="text-primary-1 text-center"
                                            />
                                        </li>
                                        <li>
                                            <Icon
                                                path={mdiStar}
                                                size={0.8}
                                                className="text-primary-1 text-center"
                                            />
                                        </li>
                                        <li>
                                            <Icon
                                                path={mdiStar}
                                                size={0.8}
                                                className="text-primary-1 text-center"
                                            />
                                        </li>
                                        <li>
                                            <Icon
                                                path={mdiStarHalf}
                                                size={0.8}
                                                className="text-primary-1 text-center"
                                            />
                                        </li>
                                    </ul>
                                    <span className="text-primary-1 lg:text-2md text-md">
                                        (
                                        {tourPackage.comments.length +
                                            generateRandomNumber()}{" "}
                                        review)
                                    </span>
                                </div>
                            </div>
                            {tourPackage.cost_per_person && (
                                <div className="pt-2">
                                    <h2 className="font-sans lg:text-[45px] leading-1.2 md:text-xl text-lg font-semibold">
                                        ${tourPackage.cost_per_person}
                                        {/* <span class="lg:text-lg text-md font-normal">Per Person</span>  */}
                                    </h2>
                                    <div className="text-md font-normal ml-1">
                                        per person
                                    </div>
                                </div>
                            )}
                        </div>
                        <div className="grid grid-cols-12 gap-base">
                            <div className="lg:col-span-8 col-span-12">
                                <div className="pack__disc">
                                    <h5 className="lg:text-2md text-md text-dark-2 font-medium leading-[1.5] font-sans mb-6">
                                        {tourPackage.title}
                                    </h5>
                                    <p>{tourPackage.description}</p>
                                    <ul className="pack__list">
                                        <li>
                                            {/* <i className="bi bi-clock" />{" "} */}
                                            <Icon
                                                path={mdiCalendar}
                                                size={0.7}
                                                className="text-black"
                                            />
                                            {tourPackage.no_of_days} Days /{" "}
                                            {tourPackage.no_of_night} Night
                                        </li>
                                        {tourPackage.max_people && (
                                            <li>
                                                {" "}
                                                {/* <i className="bi bi-person" /> */}
                                                <Icon
                                                    path={mdiNaturePeople}
                                                    size={0.7}
                                                    className="text-black"
                                                />
                                                Max People :{" "}
                                                {tourPackage.max_people}
                                            </li>
                                        )}
                                        {tourPackage.location && (
                                            <li>
                                                {/* <i className="bi bi-map" /> */}
                                                <Icon
                                                    path={mdiMapMarkerOutline}
                                                    size={0.7}
                                                    className="text-black"
                                                />
                                                {tourPackage.location}
                                            </li>
                                        )}
                                    </ul>
                                    <ul className="mt-base">
                                        <li className="lg:flex lg:pt-6 pt-5 pb-5 lg:pb-6 border-t border-stock-1 last:border-b">
                                            <div className="lg:w-1/3 lg:text-2md text-md text-dark-2 font-medium">
                                                Price Includes
                                            </div>
                                            <div className="lg:w-2/3 lg:mt-0 mt-4">
                                                <ul className="lg:grid flex flex-wrap grid-cols-2 lg:gap-y-5 gap-y-3 gap-x-3">
                                                    {tourPackage.no_of_night >
                                                        0 && (
                                                        <li className="col-span-1 text-dark-3 text-sm lg:text-base flex items-center">
                                                            <div className="text-primary-1 lg:text-md text-base mr-2">
                                                                <Icon
                                                                    path={
                                                                        mdiCheckOutline
                                                                    }
                                                                    size={0.7}
                                                                    className="text-primary-1"
                                                                />
                                                            </div>
                                                            <span>
                                                                {
                                                                    tourPackage.no_of_night
                                                                }{" "}
                                                                Nights
                                                                Accommodation
                                                            </span>
                                                        </li>
                                                    )}
                                                    {/* <li className="col-span-1 text-dark-3 text-sm lg:text-base flex items-center">
                                                        <div className="text-primary-1 lg:text-md text-base mr-2">
                                                            <Icon
                                                                path={
                                                                    mdiCheckOutline
                                                                }
                                                                size={0.7}
                                                                className="text-primary-1"
                                                            />
                                                        </div>
                                                        <span>
                                                            Airport Transfers
                                                        </span>
                                                    </li> */}
                                                    <li className="col-span-1 text-dark-3 text-sm lg:text-base flex items-center">
                                                        <div className="text-primary-1 lg:text-md text-base mr-2">
                                                            <Icon
                                                                path={
                                                                    mdiCheckOutline
                                                                }
                                                                size={0.7}
                                                                className="text-primary-1"
                                                            />
                                                        </div>
                                                        <span>
                                                            2 Meals / day
                                                        </span>
                                                    </li>
                                                    <li className="col-span-1 text-dark-3 text-sm lg:text-base flex items-center">
                                                        <div className="text-primary-1 text-md mr-2">
                                                            <Icon
                                                                path={
                                                                    mdiCheckOutline
                                                                }
                                                                size={0.7}
                                                                className="text-primary-1"
                                                            />
                                                        </div>
                                                        <span>
                                                            Box Lunch, Dinner
                                                            &amp; Snacks.
                                                        </span>
                                                    </li>
                                                    <li className="col-span-1 text-dark-3 text-sm lg:text-base flex items-center">
                                                        <div className="text-primary-1 lg:text-md text-base mr-2">
                                                            <Icon
                                                                path={
                                                                    mdiCheckOutline
                                                                }
                                                                size={0.7}
                                                                className="text-primary-1"
                                                            />
                                                        </div>
                                                        <span>Entry Fees</span>
                                                    </li>
                                                </ul>
                                            </div>
                                        </li>
                                        <li className="lg:flex lg:pt-6 pt-5 pb-5 lg:pb-6 border-t border-stock-1 last:border-b">
                                            <div className="lg:w-1/3 lg:text-2md text-md text-dark-2 font-medium">
                                                Price Excludes
                                            </div>
                                            <div className="lg:w-2/3 lg:mt-0 mt-4">
                                                <ul className="lg:grid flex flex-wrap grid-cols-2 lg:gap-y-5 gap-y-3 gap-x-3">
                                                    {/* <li className="col-span-1 text-dark-3 text-sm lg:text-base flex items-center">
                                                        <div className="text-primary-1 lg:text-md text-base mr-2">
                                                            <Icon
                                                                path={
                                                                    mdiCheckOutline
                                                                }
                                                                size={0.7}
                                                                className="text-primary-1"
                                                            />
                                                        </div>
                                                        <span>
                                                            Departure Taxes
                                                        </span>
                                                    </li> */}
                                                    <li className="col-span-1 text-dark-3 text-sm lg:text-base flex items-center">
                                                        <div className="text-primary-1 lg:text-md text-base mr-2">
                                                            <Icon
                                                                path={
                                                                    mdiCheckOutline
                                                                }
                                                                size={0.7}
                                                                className="text-primary-1"
                                                            />
                                                        </div>
                                                        <span>
                                                            Airport Transfers
                                                        </span>
                                                    </li>
                                                    {/* <li className="col-span-1 text-dark-3 text-sm lg:text-base flex items-center">
                                                        <div className="text-primary-1 lg:text-md text-base mr-2">
                                                            <Icon
                                                                path={
                                                                    mdiCheckOutline
                                                                }
                                                                size={0.7}
                                                                className="text-primary-1"
                                                            />
                                                        </div>
                                                        <span>Entry Fees</span>
                                                    </li> */}
                                                    {/* <li className="col-span-1 text-dark-3 text-sm lg:text-base flex items-center">
                                                        <div className="text-primary-1 text-md mr-2">
                                                            <Icon
                                                                path={
                                                                    mdiCheckOutline
                                                                }
                                                                size={0.7}
                                                                className="text-primary-1"
                                                            />
                                                        </div>
                                                        <span>
                                                            Box Lunch, Dinner
                                                            &amp; Snacks.
                                                        </span>
                                                    </li> */}
                                                </ul>
                                            </div>
                                        </li>
                                    </ul>
                                    <div className="mt-6">
                                        <h3>Some Photo</h3>
                                        <p>{tourPackage.image_description}</p>
                                        <div className="grid grid-cols-3 gap-5 mt-2">
                                            {tourPackage.images.map(
                                                (item, index) => {
                                                    return (
                                                        <div
                                                            className="col-span-1 cursor-pointer"
                                                            key={index}
                                                        >
                                                            <div
                                                                onClick={() =>
                                                                    showImageModal(
                                                                        item.image
                                                                    )
                                                                }
                                                            >
                                                                <img
                                                                    src={`/${item.image}`}
                                                                    alt={
                                                                        item.name
                                                                    }
                                                                    className="w-full"
                                                                />
                                                            </div>
                                                        </div>
                                                    );
                                                }
                                            )}
                                        </div>
                                    </div>
                                    <div className="lg:pt-10 pt-8">
                                        <h3>Tour Plan</h3>
                                        <p>{tourPackage.tour_plan}</p>
                                        <div>
                                            {tourPackage.packageDays.map(
                                                (item, index) => {
                                                    return (
                                                        <div
                                                            key={index}
                                                            className="flex single__count"
                                                        >
                                                            <div className="shrink-0 day__count">
                                                                <div className="lg:w-[52px] lg:h-[52px] w-10 h-10 rounded-full border border-primary-1 flex justify-center items-center lg:text-lg md:2md text-md font-semibold text-primary-1 bg-white">
                                                                    {item.day <
                                                                    10
                                                                        ? "0" +
                                                                          item.day
                                                                        : item.day}
                                                                </div>
                                                            </div>
                                                            <div className="lg:ml-[18px] ml-4 pb-8">
                                                                <h5 className="lg:text-[22px] text-md font-semibold text-dark-1 !lg:mt-[10px] !mt-2">
                                                                    Day{" "}
                                                                    {item.day <
                                                                    10
                                                                        ? "0" +
                                                                          item.day
                                                                        : item.day}
                                                                    :{" "}
                                                                    {item.title}
                                                                </h5>
                                                                <p>
                                                                    {
                                                                        item.description
                                                                    }
                                                                </p>
                                                                <ul>
                                                                    {item.option1 && (
                                                                        <li>
                                                                            <Icon
                                                                                path={
                                                                                    mdiCheckCircleOutline
                                                                                }
                                                                                size={
                                                                                    0.8
                                                                                }
                                                                                className="text-primary-1 text-center mr-2"
                                                                            />
                                                                            {
                                                                                item.option1
                                                                            }
                                                                        </li>
                                                                    )}
                                                                    {item.option2 && (
                                                                        <li>
                                                                            <Icon
                                                                                path={
                                                                                    mdiCheckCircleOutline
                                                                                }
                                                                                size={
                                                                                    0.8
                                                                                }
                                                                                className="text-primary-1 text-center mr-2"
                                                                            />
                                                                            {
                                                                                item.option2
                                                                            }
                                                                        </li>
                                                                    )}
                                                                    {item.option3 && (
                                                                        <li>
                                                                            <Icon
                                                                                path={
                                                                                    mdiCheckCircleOutline
                                                                                }
                                                                                size={
                                                                                    0.8
                                                                                }
                                                                                className="text-primary-1 text-center mr-2"
                                                                            />
                                                                            {
                                                                                item.option3
                                                                            }
                                                                        </li>
                                                                    )}
                                                                </ul>
                                                            </div>
                                                        </div>
                                                    );
                                                }
                                            )}
                                        </div>
                                    </div>
                                    {/* <AdSense.Google
                                        client="ca-pub-4460213849771600"
                                        slot="1421134476"
                                        style={{
                                            display: "block",
                                        }}
                                        layoutKey="-eb+4z+3v-fw+n2"
                                        format="fluid"
                                    />{" "} */}
                                    <Faqs />
                                    {/* <GalleryLocationComponent /> */}
                                    <div className="lg:pt-10 pt-8">
                                        <h3 className="lg:text-2xl md:text-xl text-lg text-dark-1 leading-[1.42] font-medium mt-[10px] !mb-base">
                                            {tourPackage.comments &&
                                                tourPackage.comments
                                                    .length}{" "}
                                            Comment’s
                                        </h3>
                                        <ul>
                                            {tourPackage.comments && (
                                                <>
                                                    {tourPackage.comments.map(
                                                        (item, index) => {
                                                            return (
                                                                <li className="bg-[#FFE3EB] bg-opacity-50 lg:px-base px-5 lg:py-base py-5 flex md:flex-row flex-col">
                                                                    <div className="md:mr-5 mb-4 md:mb-0 lg:w-[100px] w-16 rounded-full shrink-0">
                                                                        <img
                                                                            src="/avatar.png"
                                                                            alt="commentor"
                                                                            className="w-full rounded-full"
                                                                        />
                                                                    </div>
                                                                    <div className="grow">
                                                                        <div className="flex justify-between items-center">
                                                                            <h5 className="text-dark-1 lg:text-2md text-md font-medium !mt-0 !mb-0">
                                                                                {
                                                                                    item.name
                                                                                }
                                                                            </h5>
                                                                            <a
                                                                                href="#"
                                                                                className="flex text-primary-1 gap-[6px] text-xs lg:text-md"
                                                                            >
                                                                                Reply
                                                                            </a>
                                                                        </div>
                                                                        <p className="regular-text-v1 lg:mt-3 mt-2 !leading-[1.6] !pb-0">
                                                                            {
                                                                                item.message
                                                                            }
                                                                            .
                                                                        </p>
                                                                    </div>
                                                                </li>
                                                            );
                                                        }
                                                    )}
                                                </>
                                            )}
                                        </ul>
                                    </div>
                                    <form action="#" className="lg:pt-10 pt-8">
                                        <h3 className="lg:text-2xl md:text-xl text-lg text-dark-1 leading-[1.42] font-medium mt-[10px] !mb-base">
                                            Post A Comments
                                        </h3>
                                        <div className="grid grid-cols-2 gap-base">
                                            {!auth.user && (
                                                <>
                                                    <div className="lg:col-span-1 col-span-2">
                                                        <input
                                                            type="text"
                                                            value={name}
                                                            placeholder="Your Name"
                                                            onChange={(e) =>
                                                                setName(
                                                                    e.target
                                                                        .value
                                                                )
                                                            }
                                                            className="input_style__primary"
                                                        />
                                                    </div>
                                                    <div className="lg:col-span-1 col-span-2">
                                                        <PhoneInput
                                                            country={"uk"}
                                                            enableAreaCodes={
                                                                true
                                                            }
                                                            countryCodeEditable={
                                                                false
                                                            }
                                                            id="phone"
                                                            autoFormat={false}
                                                            name="phone"
                                                            // size="medium"
                                                            value={phone}
                                                            inputStyle={{
                                                                width: "100%",
                                                                height: "11px",
                                                                background:
                                                                    "none",
                                                            }}
                                                            onChange={(e) => {
                                                                setPhone(e);
                                                            }}
                                                            enableSearch={true}
                                                            inputProps={{
                                                                name: "phone",
                                                                // size: "large",
                                                                required: true,
                                                                autoFocus: true,
                                                            }}
                                                            isValid={(
                                                                value,
                                                                country
                                                            ) => {
                                                                if (
                                                                    value.match(
                                                                        /12345/
                                                                    )
                                                                ) {
                                                                    return (
                                                                        "Invalid value: " +
                                                                        value +
                                                                        ", " +
                                                                        country.name
                                                                    );
                                                                } else if (
                                                                    value.match(
                                                                        /12345/
                                                                    )
                                                                ) {
                                                                    return false;
                                                                } else if (
                                                                    value.match(
                                                                        /1111111/
                                                                    )
                                                                ) {
                                                                    return false;
                                                                } else if (
                                                                    value.match(
                                                                        /000000/
                                                                    )
                                                                ) {
                                                                    return false;
                                                                } else {
                                                                    setCountry(
                                                                        country.name
                                                                    );
                                                                    return true;
                                                                }
                                                            }}
                                                        />
                                                    </div>
                                                    <div className="col-span-2">
                                                        <input
                                                            type="email"
                                                            value={email}
                                                            onChange={(e) =>
                                                                setEmail(
                                                                    e.target
                                                                        .value
                                                                )
                                                            }
                                                            placeholder="Your Email"
                                                            className="input_style__primary"
                                                        />
                                                    </div>
                                                </>
                                            )}
                                            <div className="col-span-2">
                                                <textarea
                                                    cols={30}
                                                    value={message}
                                                    rows={6}
                                                    onChange={(e) =>
                                                        setMessage(
                                                            e.target.value
                                                        )
                                                    }
                                                    className="input_style__primary"
                                                    placeholder="Your Message..."
                                                    defaultValue={""}
                                                />
                                            </div>
                                            <div className="col-span-2">
                                                {loading ? (
                                                    <Button
                                                        variant="contained"
                                                        disabled={true}
                                                    >
                                                        Posting...
                                                    </Button>
                                                ) : (
                                                    <button
                                                        type="submit"
                                                        onClick={(e) => {
                                                            e.preventDefault();
                                                            setLoading(true);
                                                            // console.log({
                                                            //     package_id:
                                                            //         tourPackage.id,
                                                            //     name,
                                                            //     email,
                                                            //     phone,
                                                            //     message,
                                                            // });
                                                            router.post(
                                                                "/post-comment",
                                                                {
                                                                    package_id:
                                                                        tourPackage.id,
                                                                    name,
                                                                    email,
                                                                    phone,
                                                                    message,
                                                                }
                                                            );
                                                        }}
                                                        className="btn_primary__v1"
                                                        // disabled={true}
                                                    >
                                                        Post
                                                        {/* <i className="bi bi-chevron-right" /> */}
                                                    </button>
                                                )}
                                            </div>
                                        </div>
                                    </form>
                                </div>
                            </div>
                            <div className="lg:col-span-4 col-span-12 ">
                                {/* <ul
                                    id="tabs-nav"
                                    className="booking-tabs flex gap-4 pb-6"
                                >
                                    <li
                                        className="tab-link active basis-1/2"
                                        data-tab={3}
                                    >
                                        Booking
                                    </li>
                                    <li
                                        className="tab-link basis-1/2"
                                        data-tab={4}
                                    >
                                        Enquiry
                                    </li>
                                </ul> */}
                                {/* <div>
                                    {" "} */}
                                <Box>
                                    <Tabs
                                        value={tabValue}
                                        onChange={handleChange}
                                        indicatorColor="secondary"
                                        textColor="inherit"
                                        variant="fullWidth"
                                        aria-label="full width tabs example"
                                    >
                                        <Tab
                                            label="BOOKING"
                                            {...a11yProps(0)}
                                        />

                                        <Tab
                                            label="INQUIRE"
                                            {...a11yProps(1)}
                                        />
                                    </Tabs>
                                </Box>
                                {/* </div> */}

                                <SwipeableViews
                                    // axis={
                                    //     theme.direction === "rtl"
                                    //         ? "x-reverse"
                                    //         : "x"
                                    // }
                                    index={tabValue}
                                    onChangeIndex={handleChangeIndex}
                                >
                                    {/* <TabPanel
                                        value={tabValue}
                                        index={0}
                                        // dir={theme.direction}
                                    > */}
                                    <div
                                        id="tab-3"
                                        className="tab-content active mt-5"
                                    >
                                        <>
                                            <form
                                                // action="#"
                                                // autoComplete="off"
                                                className="lg:px-base px-5 lg:pt-6 lg:pb-base pt-4 pb-5 bg-white border-primary-1 border"
                                            >
                                                <h4 className="lg:text-xl text-lg text-dark-1 font-semibold">
                                                    <span className="text-md font-sans font-normal text-dark-3">
                                                        Start from
                                                    </span>{" "}
                                                    ${tourPackage.starting_cost}
                                                </h4>
                                                <div className="mt-5 lg:mt-6 z-30">
                                                    <LocalizationProvider
                                                        dateAdapter={
                                                            AdapterDayjs
                                                        }
                                                    >
                                                        <DemoContainer
                                                            components={
                                                                [
                                                                    // "DateRangePicker",
                                                                    // "DateRangePicker",
                                                                ]
                                                            }
                                                        >
                                                            <DemoItem
                                                                label="Choose Date"
                                                                // component="DateRangePicker"
                                                            >
                                                                <DateRangePicker
                                                                    value={
                                                                        value
                                                                    }
                                                                    onChange={(
                                                                        newValue
                                                                    ) =>
                                                                        setValue(
                                                                            newValue
                                                                        )
                                                                    }
                                                                />
                                                            </DemoItem>
                                                        </DemoContainer>
                                                    </LocalizationProvider>
                                                </div>
                                                <div className="js-form-counters lg:mt-6 mt-5 relative">
                                                    <label
                                                        htmlFor="tourTime"
                                                        className="mb-2 text-dark-3 capitalize block"
                                                    >
                                                        Number of people
                                                    </label>
                                                    <div
                                                        onClick={() =>
                                                            setShowDropDown(
                                                                !showDropDown
                                                            )
                                                        }
                                                        className="w-full cursor-pointer bg-transparent border border-stock-1 lg:h-[54px] h-12 px-5 py-2 text-dark-2 focus:border-primary-1 flex items-center common_dropdown__btn"
                                                    >
                                                        <div>
                                                            <span className="js-count-adult">
                                                                {adultCount}
                                                            </span>{" "}
                                                            adults -{" "}
                                                            <span className="js-count-child">
                                                                {childCount}
                                                            </span>{" "}
                                                            children -{" "}
                                                            <span className="js-count-room">
                                                                {roomCount}
                                                            </span>{" "}
                                                            room
                                                        </div>
                                                    </div>
                                                    {/* count dropdown */}
                                                    {showDropDown && (
                                                        <div
                                                            className="mt-2"
                                                            //  className="common__dropdown person-dropdown space-y-4 opacity-0 absolute w-full left-0 top-full invisiblee bg-white translate-y-3 duration-200 z-10"
                                                        >
                                                            {/* adult count */}
                                                            <div className="js-counter flex justify-between items-center">
                                                                <p className="text-dark-1">
                                                                    Adult
                                                                </p>
                                                                <div className="flex items-center space-x-4">
                                                                    <div
                                                                        // type="button"
                                                                        className="js-down h-[38px] cursor-pointer w-[38px] border border-primary-1 flex items-center justify-center rounded-full text-dark-1 hover:bg-primary-1 hover:text-white duration-150"
                                                                        onClick={() =>
                                                                            handleDecrement(
                                                                                "adult"
                                                                            )
                                                                        }
                                                                    >
                                                                        {/* <Icon
                                                                        path={
                                                                            mdiMinus
                                                                        }
                                                                        size={1}
                                                                        className="text-primary-1 text-center"
                                                                    /> */}
                                                                        <Icon
                                                                            path={
                                                                                mdiMinus
                                                                            }
                                                                            size={
                                                                                1
                                                                            }
                                                                            className="text-primary-1 hover:text-white text-center"
                                                                        />
                                                                    </div>
                                                                    <div className="js-count text-dark-1 lg:ext-md">
                                                                        {
                                                                            adultCount
                                                                        }
                                                                    </div>
                                                                    <div
                                                                        // type="button"
                                                                        className="js-up h-[38px] cursor-pointer w-[38px] border border-primary-1 flex items-center justify-center rounded-full text-dark-1 hover:bg-primary-1 hover:text-white duration-150"
                                                                        onClick={(
                                                                            e
                                                                        ) => {
                                                                            e.preventDefault();
                                                                            handleIncrement(
                                                                                "adult"
                                                                            );
                                                                        }}
                                                                    >
                                                                        {/* <Icon
                                                                        path={
                                                                            mdiPlus
                                                                        }
                                                                        size={1}
                                                                        className="text-primary-1 text-center"
                                                                    /> */}
                                                                        <Icon
                                                                            path={
                                                                                mdiPlus
                                                                            }
                                                                            size={
                                                                                1
                                                                            }
                                                                            className="text-primary-1 text-center hover:text-white"
                                                                        />
                                                                    </div>
                                                                </div>
                                                            </div>
                                                            {/* children count  */}
                                                            <div className="js-counter flex justify-between items-center">
                                                                <p className="text-dark-1">
                                                                    Children
                                                                </p>
                                                                <div className="flex items-center space-x-4">
                                                                    <div
                                                                        // type="button"
                                                                        className="js-down cursor-pointer h-[38px] w-[38px] border border-primary-1 flex items-center justify-center rounded-full text-dark-1 hover:bg-primary-1 hover:text-white duration-150"
                                                                        onClick={() =>
                                                                            handleDecrement(
                                                                                "child"
                                                                            )
                                                                        }
                                                                    >
                                                                        <Icon
                                                                            path={
                                                                                mdiMinus
                                                                            }
                                                                            size={
                                                                                1
                                                                            }
                                                                            className="text-primary-1 text-center hover:text-white"
                                                                        />
                                                                    </div>
                                                                    <div className="js-count text-dark-1 lg:ext-md">
                                                                        {
                                                                            childCount
                                                                        }
                                                                    </div>
                                                                    <button
                                                                        // type="button"
                                                                        className="js-up h-[38px] w-[38px] border border-primary-1 flex items-center justify-center rounded-full text-dark-1 hover:bg-primary-1 hover:text-white duration-150"
                                                                        onClick={() =>
                                                                            handleIncrement(
                                                                                "child"
                                                                            )
                                                                        }
                                                                    >
                                                                        <Icon
                                                                            path={
                                                                                mdiPlus
                                                                            }
                                                                            size={
                                                                                1
                                                                            }
                                                                            className="text-primary-1 text-center hover:text-white "
                                                                        />
                                                                    </button>
                                                                </div>
                                                            </div>
                                                            {/* room count */}
                                                            <div className="js-counter flex justify-between items-center">
                                                                <p className="text-dark-1">
                                                                    Room
                                                                </p>
                                                                <div className="flex items-center space-x-4">
                                                                    <button
                                                                        type="button"
                                                                        className="js-down h-[38px] w-[38px] border border-primary-1 flex items-center justify-center rounded-full text-dark-1 hover:bg-primary-1 hover:text-white duration-150"
                                                                        onClick={() =>
                                                                            handleDecrement(
                                                                                "room"
                                                                            )
                                                                        }
                                                                    >
                                                                        <Icon
                                                                            path={
                                                                                mdiMinus
                                                                            }
                                                                            size={
                                                                                1
                                                                            }
                                                                            className="text-primary-1 text-center hover:text-white "
                                                                        />
                                                                    </button>
                                                                    <div className="js-count text-dark-1 lg:ext-md">
                                                                        {
                                                                            roomCount
                                                                        }
                                                                    </div>
                                                                    <button
                                                                        type="button"
                                                                        className="js-up h-[38px] w-[38px] border border-primary-1 flex items-center justify-center rounded-full text-dark-1 hover:bg-primary-1 hover:text-white duration-150"
                                                                        onClick={() =>
                                                                            handleIncrement(
                                                                                "room"
                                                                            )
                                                                        }
                                                                    >
                                                                        <Icon
                                                                            path={
                                                                                mdiPlus
                                                                            }
                                                                            size={
                                                                                1
                                                                            }
                                                                            className="text-primary-1 text-center hover:text-white "
                                                                        />
                                                                    </button>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    )}
                                                    <>
                                                        {!auth.user && (
                                                            <>
                                                                <div className="lg:mt-base mt-5">
                                                                    <input
                                                                        type="text"
                                                                        placeholder="Your Name"
                                                                        value={
                                                                            name
                                                                        }
                                                                        onChange={(
                                                                            e
                                                                        ) =>
                                                                            setName(
                                                                                e
                                                                                    .target
                                                                                    .value
                                                                            )
                                                                        }
                                                                        className="input_style__primary"
                                                                    />
                                                                </div>
                                                                <div className="lg:mt-base mt-5">
                                                                    <input
                                                                        type="email"
                                                                        placeholder="Email"
                                                                        value={
                                                                            email
                                                                        }
                                                                        onChange={(
                                                                            e
                                                                        ) =>
                                                                            setEmail(
                                                                                e
                                                                                    .target
                                                                                    .value
                                                                            )
                                                                        }
                                                                        className="input_style__primary"
                                                                    />
                                                                </div>
                                                                <div className="lg:mt-base mt-5">
                                                                    {/* <input
                                                                        type="tel"
                                                                        value={
                                                                            phone
                                                                        }
                                                                        onChange={(
                                                                            e
                                                                        ) =>
                                                                            setPhone(
                                                                                e
                                                                                    .target
                                                                                    .value
                                                                            )
                                                                        }
                                                                        placeholder="Mobile Number"
                                                                        className="input_style__primary"
                                                                    /> */}
                                                                    <PhoneInput
                                                                        country={
                                                                            "uk"
                                                                        }
                                                                        enableAreaCodes={
                                                                            true
                                                                        }
                                                                        countryCodeEditable={
                                                                            false
                                                                        }
                                                                        id="phone"
                                                                        autoFormat={
                                                                            false
                                                                        }
                                                                        name="phone"
                                                                        // size="medium"
                                                                        value={
                                                                            phone
                                                                        }
                                                                        inputStyle={{
                                                                            width: "100%",
                                                                            height: "11px",
                                                                            background:
                                                                                "none",
                                                                        }}
                                                                        onChange={(
                                                                            e
                                                                        ) => {
                                                                            setPhone(
                                                                                e
                                                                            );
                                                                        }}
                                                                        enableSearch={
                                                                            true
                                                                        }
                                                                        inputProps={{
                                                                            name: "phone",
                                                                            size: "small",
                                                                            required: true,
                                                                            autoFocus: true,
                                                                        }}
                                                                        isValid={(
                                                                            value,
                                                                            country
                                                                        ) => {
                                                                            if (
                                                                                value.match(
                                                                                    /12345/
                                                                                )
                                                                            ) {
                                                                                return (
                                                                                    "Invalid value: " +
                                                                                    value +
                                                                                    ", " +
                                                                                    country.name
                                                                                );
                                                                            } else if (
                                                                                value.match(
                                                                                    /12345/
                                                                                )
                                                                            ) {
                                                                                return false;
                                                                            } else if (
                                                                                value.match(
                                                                                    /1111111/
                                                                                )
                                                                            ) {
                                                                                return false;
                                                                            } else if (
                                                                                value.match(
                                                                                    /000000/
                                                                                )
                                                                            ) {
                                                                                return false;
                                                                            } else {
                                                                                setCountry(
                                                                                    country.name
                                                                                );
                                                                                return true;
                                                                            }
                                                                        }}
                                                                    />
                                                                </div>
                                                            </>
                                                        )}
                                                    </>
                                                    <div className="lg:mt-base mt-5">
                                                        <textarea
                                                            cols={30}
                                                            value={message}
                                                            onChange={(e) =>
                                                                setMessage(
                                                                    e.target
                                                                        .value
                                                                )
                                                            }
                                                            rows={6}
                                                            className="input_style__primary"
                                                            placeholder="Message (if any)"
                                                            defaultValue={""}
                                                        />
                                                    </div>
                                                </div>
                                                {/* <div className="pt-4">
                                                <div className="custom-checkbox mt-4">
                                                    <input
                                                        type="checkbox"
                                                        defaultValue="add-one"
                                                        id="add-one"
                                                    />
                                                    <label htmlFor="add-one">
                                                        Add Service per booking
                                                        -{" "}
                                                        <span className="font-semibold">
                                                            $30
                                                        </span>
                                                    </label>
                                                </div>
                                                <div className="custom-checkbox mt-4">
                                                    <input
                                                        type="checkbox"
                                                        defaultValue="add-two"
                                                        id="add-two"
                                                    />
                                                    <label htmlFor="add-two">
                                                        Add Service per day -{" "}
                                                        <span className="font-semibold">
                                                            $10
                                                        </span>
                                                    </label>
                                                </div>
                                            </div>
                                            <div className="pt-5 border-t border-stock-1 mt-6">
                                                <div className="font-sans text-dark-1 text-2md font-semibold flex justify-between">
                                                    Total : <span>$450</span>
                                                </div>
                                            </div> */}
                                                {/* <button className="capitalize w-full text-center underline duration-150 mt-4 text-dark-1 font-medium flex items-center justify-center hover:text-primary-1">
                                                check availability{" "}
                                            </button> */}
                                                {loading ? (
                                                    <Button
                                                        variant="contained"
                                                        disabled={true}
                                                    >
                                                        Loading...
                                                    </Button>
                                                ) : (
                                                    <button
                                                        href="booking.html"
                                                        className="btn_primary__v1 !w-full justify-center mt-5"
                                                        onClick={(e) => {
                                                            e.preventDefault();
                                                            setLoading(true);
                                                            console.log(
                                                                value[0].$d
                                                                // package_id:
                                                                //     tourPackage.id,
                                                                // name,
                                                                // email,
                                                                // country,
                                                                // phone,
                                                                // message,
                                                                // adultCount,
                                                                // childCount,
                                                                // roomCount,
                                                            );
                                                            // return;
                                                            router.post(
                                                                "/book-package",
                                                                {
                                                                    package_id:
                                                                        tourPackage.id,
                                                                    name,
                                                                    email,
                                                                    phone,
                                                                    message,
                                                                    country,
                                                                    adultCount,
                                                                    childCount,
                                                                    roomCount,
                                                                    dateEnd:
                                                                        value[1]
                                                                            .$d,
                                                                    dateStart:
                                                                        value[0]
                                                                            .$d,
                                                                }
                                                            );
                                                        }}
                                                    >
                                                        Book Now
                                                        <svg
                                                            width={20}
                                                            height={20}
                                                            viewBox="0 0 20 20"
                                                            fill="none"
                                                            xmlns="http://www.w3.org/2000/svg"
                                                        >
                                                            <path
                                                                d="M7.42505 16.5999L12.8584 11.1666C13.5 10.5249 13.5 9.4749 12.8584 8.83324L7.42505 3.3999"
                                                                stroke="currentColor"
                                                                strokeWidth="1.5"
                                                                strokeMiterlimit={
                                                                    10
                                                                }
                                                                strokeLinecap="round"
                                                                strokeLinejoin="round"
                                                            />
                                                        </svg>
                                                    </button>
                                                )}
                                            </form>
                                        </>
                                    </div>
                                    {/* </TabPanel> */}
                                    {/* <TabPanel
                                        value={tabValue}
                                        index={1}
                                        // dir={theme.direction}
                                    > */}
                                    {/* {tabValue == 1 && ( */}
                                    {tabValue == 1 && (
                                        <div
                                            id="tab-4"
                                            className="tab-content active mt-5"
                                        >
                                            <form
                                                // action="#"
                                                className="lg:px-base px-5 lg:py-base py-5 bg-white border-primary-1 border"
                                            >
                                                <h4 className="lg:text-lg text-2md text-dark-1 font-semibold">
                                                    Enquiry Now
                                                </h4>
                                                <p className="regular-text-v1 !leading-[1.62] mt-2">
                                                    Ask Anything.
                                                </p>
                                                {!auth.user && (
                                                    <>
                                                        <div className="lg:mt-base mt-5">
                                                            <input
                                                                type="text"
                                                                placeholder="Your Name"
                                                                value={name}
                                                                onChange={(e) =>
                                                                    setName(
                                                                        e.target
                                                                            .value
                                                                    )
                                                                }
                                                                className="input_style__primary"
                                                            />
                                                        </div>
                                                        <div className="lg:mt-base mt-5">
                                                            <input
                                                                type="email"
                                                                placeholder="Email"
                                                                value={email}
                                                                onChange={(e) =>
                                                                    setEmail(
                                                                        e.target
                                                                            .value
                                                                    )
                                                                }
                                                                className="input_style__primary"
                                                            />
                                                        </div>
                                                        <div className="lg:mt-base mt-5">
                                                            <PhoneInput
                                                                country={"uk"}
                                                                enableAreaCodes={
                                                                    true
                                                                }
                                                                countryCodeEditable={
                                                                    false
                                                                }
                                                                id="phone"
                                                                autoFormat={
                                                                    false
                                                                }
                                                                name="phone"
                                                                // size="medium"
                                                                value={phone}
                                                                inputStyle={{
                                                                    width: "100%",
                                                                    height: "11px",
                                                                    background:
                                                                        "none",
                                                                }}
                                                                onChange={(
                                                                    e
                                                                ) => {
                                                                    setPhone(e);
                                                                }}
                                                                enableSearch={
                                                                    true
                                                                }
                                                                inputProps={{
                                                                    name: "phone",
                                                                    size: "small",
                                                                    required: true,
                                                                    autoFocus: true,
                                                                }}
                                                                isValid={(
                                                                    value,
                                                                    country
                                                                ) => {
                                                                    if (
                                                                        value.match(
                                                                            /12345/
                                                                        )
                                                                    ) {
                                                                        return (
                                                                            "Invalid value: " +
                                                                            value +
                                                                            ", " +
                                                                            country.name
                                                                        );
                                                                    } else if (
                                                                        value.match(
                                                                            /12345/
                                                                        )
                                                                    ) {
                                                                        return false;
                                                                    } else if (
                                                                        value.match(
                                                                            /1111111/
                                                                        )
                                                                    ) {
                                                                        return false;
                                                                    } else if (
                                                                        value.match(
                                                                            /000000/
                                                                        )
                                                                    ) {
                                                                        return false;
                                                                    } else {
                                                                        setCountry(
                                                                            country.name
                                                                        );
                                                                        return true;
                                                                    }
                                                                }}
                                                            />
                                                        </div>
                                                    </>
                                                )}
                                                <div className="lg:mt-base mt-5">
                                                    <textarea
                                                        cols={30}
                                                        value={message}
                                                        onChange={(e) =>
                                                            setMessage(
                                                                e.target.value
                                                            )
                                                        }
                                                        rows={6}
                                                        className="input_style__primary"
                                                        placeholder="Message..."
                                                        defaultValue={""}
                                                    />
                                                </div>
                                                {loading ? (
                                                    <Button
                                                        variant="contained"
                                                        disabled={true}
                                                    >
                                                        Posting...
                                                    </Button>
                                                ) : (
                                                    <button
                                                        className="btn_primary__v1 !w-full justify-center mt-5"
                                                        onClick={(e) => {
                                                            e.preventDefault();
                                                            setLoading(true);
                                                            // console.log({
                                                            //     package_id:
                                                            //         tourPackage.id,
                                                            //     name,
                                                            //     email,
                                                            //     phone,
                                                            //     message,
                                                            // });
                                                            router.post(
                                                                "/post-enquiry",
                                                                {
                                                                    package_id:
                                                                        tourPackage.id,
                                                                    name,
                                                                    email,
                                                                    phone,
                                                                    message,
                                                                }
                                                            );
                                                        }}
                                                    >
                                                        Enquiry
                                                        <svg
                                                            width={20}
                                                            height={20}
                                                            viewBox="0 0 20 20"
                                                            fill="none"
                                                            xmlns="http://www.w3.org/2000/svg"
                                                        >
                                                            <path
                                                                d="M7.42505 16.5999L12.8584 11.1666C13.5 10.5249 13.5 9.4749 12.8584 8.83324L7.42505 3.3999"
                                                                stroke="currentColor"
                                                                strokeWidth="1.5"
                                                                strokeMiterlimit={
                                                                    10
                                                                }
                                                                strokeLinecap="round"
                                                                strokeLinejoin="round"
                                                            />
                                                        </svg>
                                                    </button>
                                                )}
                                            </form>
                                        </div>
                                    )}
                                    {/* </TabPanel> */}
                                </SwipeableViews>
                                <OfferPackages />
                            </div>
                        </div>
                    </div>
                </div>

                {/*========== BLOG STYLE ONE END ==========*/}
                {/*========== INSTAGRAM FEED STYLE START ==========*/}
                {/* <InstagramFeeds /> */}
                {/*========== INSTAGRAM FEED STYLE END ==========*/}
                {/*========== FOOTER STYLE START ==========*/}
                <Footer />
                {/*========== FOOTER STYLE END ==========*/}
                {/* additional JS file */}
                {/* custom js file */}
            </div>
        </>
    );
}
